## 7.44.8 (2022-04-16)

Python 3 stubs: use `str` instead of `typing.Text` (#7638)

## 7.44.7 (2022-02-21)

contextvars, pycurl: make classes final (#7334)

## 7.44.5 (2022-01-02)

Never explicitly inherit from `object` in Python 3-only stubs (#6777)

## 7.44.4 (2021-12-28)

Use PEP 585 syntax wherever possible (#6717)

## 7.44.3 (2021-12-27)

Replace METADATA stubtest key with stubtest_apt_packages (#6704)

## 7.44.2 (2021-12-25)

Add a 'stubtest' flag to METADATA.toml (#6687)

Co-authored-by: Akuli <akuviljanen17@gmail.com>

## 7.44.1 (2021-10-15)

Use lowercase tuple where possible (#6170)

## 7.44.0 (2021-10-12)

Update remaining versions for third-party stubs (#6094)

Also remove the python2 markers of packages that don't list Python 2
as supported in the latest version.

Don't special case version '0.1'

Co-authored-by: Akuli <akuviljanen17@gmail.com>

